==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/APPLICATIONFILETYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for APPLICATIONFILETYPE_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="APPLICATIONFILETYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOGTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPLICATIONFILETYPE_Type", propOrder = {
    "filetype",
    "logtype"
})
public class APPLICATIONFILETYPE_Type {

    @XmlElement(name = "FILETYPE", required = true)
    protected String filetype;
    @XmlElement(name = "LOGTYPE")
    protected String logtype;

    /**
     * Gets the value of the filetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILETYPE() {
        return filetype;
    }

    /**
     * Sets the value of the filetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILETYPE(String value) {
        this.filetype = value;
    }

    /**
     * Gets the value of the logtype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOGTYPE() {
        return logtype;
    }

    /**
     * Sets the value of the logtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOGTYPE(String value) {
        this.logtype = value;
    }

}

==> eam-wshub-proxyclient-11.4-9-sources.jar: net/datastream/schemas/mp_fields/APPLICATIONFILETYPE_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour APPLICATIONFILETYPE_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="APPLICATIONFILETYPE_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FILETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOGTYPE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "APPLICATIONFILETYPE_Type", propOrder = {
    "filetype",
    "logtype"
})
public class APPLICATIONFILETYPE_Type {

    @XmlElement(name = "FILETYPE", required = true)
    protected String filetype;
    @XmlElement(name = "LOGTYPE")
    protected String logtype;

    /**
     * Obtient la valeur de la propriété filetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFILETYPE() {
        return filetype;
    }

    /**
     * Définit la valeur de la propriété filetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFILETYPE(String value) {
        this.filetype = value;
    }

    /**
     * Obtient la valeur de la propriété logtype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOGTYPE() {
        return logtype;
    }

    /**
     * Définit la valeur de la propriété logtype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOGTYPE(String value) {
        this.logtype = value;
    }

}
